@@ -434,8 +434,8 @@ def adjNVmatch(text5):
   matcher = Matcher(nlp.vocab)
   # Add with ID, optional callback and pattern(s)
 
-  pattern = [{"POS": "NOUN","OP":"+"},{"LOWER": "be","OP":"+"}, {"POS": "ADV","OP":"*"},{"POS": "ADJ","OP":"+"}] #"OP":"+" 1 or more * 0 or more # ugly and expensive ugly is adj, ugly expensive ugly is adv
-  matcher.add('NA+adj', [pattern])
+  pattern = [{"POS": "ADJ","OP":"*"},{"POS": "NOUN","OP":"+"},{"LOWER": "be","OP":"+"}, {"POS": "ADV","OP":"*"},{"POS": "ADJ","OP":"+"}] #"OP":"+" 1 or more * 0 or more # ugly and expensive ugly is adj, ugly expensive ugly is adv
+  matcher.add('(A)N+A', [pattern])
   #pattern2 =[{"LIKE_EMAIL":True}]
   pattern2 = [{"POS": "ADJ","OP":"+"},{"POS": "NOUN","OP":"+"}]
   matcher.add('A+N', [pattern2])
